@@ -44,6 +44,12 @@ FAILEDOPERATION_NOPAYMENT = 'FailedOperation.NoPayment'
 # 用户未实名认证。
 FAILEDOPERATION_NOTAUTHENTICATED = 'FailedOperation.NotAuthenticated'
 
+# 不支持在滚动重启扩容计算资源同时扩容磁盘数量。
+FAILEDOPERATION_UNSUPPORTRESETNODETYPEANDSCALEOUTDISK = 'FailedOperation.UnsupportResetNodeTypeAndScaleoutDisk'
+
+# 不支持滚动缩容计算资源同时修改磁盘大小。
+FAILEDOPERATION_UNSUPPORTRESETSCALEDOWNANDMODIFYDISK = 'FailedOperation.UnsupportResetScaledownAndModifyDisk'
+
 # 不支持反向调节节点配置和磁盘容量。
 FAILEDOPERATION_UNSUPPORTREVERSEREGULATIONNODETYPEANDDISK = 'FailedOperation.UnsupportReverseRegulationNodeTypeAndDisk'
 
