@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -166,6 +166,34 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeViews(self, request):
+        """查询集群各视图数据，包括集群维度、节点维度、Kibana维度
+
+        :param request: Request instance for DescribeViews.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeViewsRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeViewsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeViews", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeViewsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DiagnoseInstance(self, request):
         """智能运维诊断集群
 
@@ -334,6 +362,34 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateDictionaries(self, request):
+        """更新ES集群词典
+
+        :param request: Request instance for UpdateDictionaries.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateDictionariesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateDictionariesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateDictionaries", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateDictionariesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateInstance(self, request):
         """对集群进行节点规格变更，修改实例名称，修改配置，重置密码， 添加Kibana黑白名单等操作。参数中InstanceId为必传参数，ForceRestart为选填参数，剩余参数传递组合及含义如下：
         - InstanceName：修改实例名称(仅用于标识实例)
@@ -369,6 +425,34 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateJdk(self, request):
+        """更新实例Jdk配置
+
+        :param request: Request instance for UpdateJdk.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateJdkRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateJdkResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateJdk", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateJdkResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdatePlugins(self, request):
         """变更插件列表
 
